=======
Credits
=======

Development Lead
----------------

* Costas Tyfoxylos <ctyfoxylos@schubergphilis.com>

Contributors
------------

* Michael Wiley <michaeltwiley@gmail.com>
* Anton Opgenoort <aopgenoort@schubergphilis.com>
* Gareth Hawker <ghawker@schubergphilis.com>
* Ilija Matoski <imatoski@schubergphilis.com>
* Yorick Hoorneman <yhoorneman@schubergphilis.com>
* Howard Jones <howie@thingy.com>
* Octavian Balas <octavian.balas@gmail.com>
* Philipp Hoffmann <phoffmann@spirit21.com>
* Iqbal Nazir <iqbalnazirsumon@gmail.com>
* Jeremy Shade <jeremy.shade@outlook.com>